@@ -39,7 +39,7 @@
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * $Id: append.c,v 1.118 2009/03/16 00:17:14 brong Exp $
+ * $Id: append.c,v 1.121 2009/06/29 17:39:31 murch Exp $
  */
 
 #include <config.h>
@@ -69,6 +69,7 @@
 #include "seen.h"
 #include "retry.h"
 #include "quota.h"
+#include "util.h"
 
 #include "message_guid.h"
 
@@ -324,7 +325,7 @@ int append_commit(struct appendstate *as,
     else {
 	quota_abort(&as->tid);
 	syslog(LOG_ERR,
-	       "LOSTQUOTA: unable to record use of %u bytes in quota file %s",
+	       "LOSTQUOTA: unable to record use of " UQUOTA_T_FMT " bytes in quota file %s",
 	       as->quota_used, as->m.quota.root);
     }
 
@@ -1047,7 +1048,7 @@ static void addme(char **msgrange, int *alloced, long uid)
 
 	/* see what the last one is */
 	p = *msgrange + len - 1;
-	while (isdigit((int) *p) && p > *msgrange) p--;
+	while (Uisdigit(*p) && p > *msgrange) p--;
 	/* second time, p == msgrange here */
 	if (*p == ':') wasrange = 1;
 	p++;
@@ -1095,7 +1096,10 @@ static int append_addseen(struct mailbox *mailbox,
     if (r) return r;
     
     r = seen_lockread(seendb, &last_read, &last_uid, &last_change, &seenuids);
-    if (r) return r;
+    if (r) {
+	seen_close(seendb);
+	return r;
+    }
     
     oldlen = strlen(seenuids);
     newlen = oldlen + strlen(msgrange) + 10;
@@ -1103,7 +1107,7 @@ static int append_addseen(struct mailbox *mailbox,
 
     tail = seenuids + oldlen;
     /* Scan back to last uid */
-    while (tail > seenuids && isdigit((int) tail[-1])) tail--;
+    while (tail > seenuids && Uisdigit(tail[-1])) tail--;
     for (p = tail, last_seen=0; *p; p++) last_seen = last_seen * 10 + *p - '0';
     if (last_seen && last_seen >= start-1) {
 	if (tail > seenuids && tail[-1] == ':') p = tail - 1;
