@@ -39,7 +39,7 @@
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * $Id: imap_proxy.c,v 1.12 2009/02/09 05:01:56 brong Exp $
+ * $Id: imap_proxy.c,v 1.17 2009/07/24 15:15:43 murch Exp $
  */
 
 #include <config.h>
@@ -62,6 +62,7 @@
 #include "mboxname.h"
 #include "mupdate-client.h"
 #include "prot.h"
+#include "util.h"
 #include "xmalloc.h"
 #include "xstrlcat.h"
 
@@ -110,6 +111,7 @@ struct protocol_t imap_protocol =
   { "C01 CAPABILITY", NULL, "C01 ", &imap_parsemechlist,
     { { " AUTH=", CAPA_AUTH },
       { " STARTTLS", CAPA_STARTTLS },
+      { " COMPRESS=DEFLATE", CAPA_COMPRESS },
       { " IDLE", CAPA_IDLE },
       { " MUPDATE", CAPA_MUPDATE },
       { " MULTIAPPEND", CAPA_MULTIAPPEND },
@@ -118,6 +120,7 @@ struct protocol_t imap_protocol =
       { NULL, 0 } } },
   { "S01 STARTTLS", "S01 OK", "S01 NO", 0 },
   { "A01 AUTHENTICATE", 0, 0, "A01 OK", "A01 NO", "+ ", "*", NULL, 0 },
+  { "Z01 COMPRESS DEFLATE", "* ", "Z01 OK" },
   { "N01 NOOP", "* ", "N01 OK" },
   { "Q01 LOGOUT", "* ", "Q01 " }
 };
@@ -271,7 +274,7 @@ static int pipe_response(struct backend *s, const char *tag, int include_last,
 		eol[i-1] == '\n' && eol[i-2] == '\r' && eol[i-3] == '}') {
 		/* possible literal */
 		i -= 4;
-		while (i > 0 && eol[i] != '{' && isdigit((int) eol[i])) {
+		while (i > 0 && eol[i] != '{' && Uisdigit(eol[i])) {
 		    i--;
 		}
 		if (eol[i] == '{') {
@@ -392,7 +395,7 @@ int pipe_command(struct backend *s, int optimistic_literal)
 		    nonsynch = 1;
 		    i--;
 		}
-		while (i > 0 && eol[i] != '{' && isdigit((int) eol[i])) {
+		while (i > 0 && eol[i] != '{' && Uisdigit(eol[i])) {
 		    i--;
 		}
 		if (eol[i] == '{') {
@@ -1374,3 +1377,100 @@ int annotate_store_proxy(const char *server, const char *mbox_pat,
 
     return 0;
 }
+
+
+char *find_free_server()
+{
+    const char *servers = config_getstring(IMAPOPT_SERVERLIST);
+    unsigned long max_avail = 0;
+    char *server = NULL;
+
+    if (servers) {
+	char *tmpbuf, *cur_server, *next_server;
+	char mytag[128];
+	struct backend *be;
+
+	/* make a working copy of the list */
+	cur_server = tmpbuf = xstrdup(servers);
+
+	while (cur_server) {
+	    /* eat any leading whitespace */
+	    while (Uisspace(*cur_server)) cur_server++;
+
+	    if (!*cur_server) break;
+
+	    /* find end of server */
+	    if ((next_server = strchr(cur_server, ' ')) ||
+		(next_server = strchr(cur_server, '\t')))
+		*next_server++ = '\0';
+
+	    syslog(LOG_DEBUG, "checking free space on server '%s'", cur_server);
+
+	    /* connect to server */
+	    be = proxy_findserver(cur_server, &imap_protocol,
+				  proxy_userid, &backend_cached,
+				  &backend_current, &backend_inbox, imapd_in);
+	    if (be) {
+		unsigned long avail = 0;
+		int c;
+
+		/* fetch annotation from remote */
+		proxy_gentag(mytag, sizeof(mytag));
+		prot_printf(be->out,
+			    "%s GETANNOTATION \"\" "
+			    "\"/vendor/cmu/cyrus-imapd/freespace\" "
+			    "\"value.shared\"\r\n", mytag);
+		prot_flush(be->out);
+
+		for (/* each annotation response */;;) {
+		    /* read a line */
+		    c = prot_getc(be->in);
+		    if (c != '*') break;
+		    c = prot_getc(be->in);
+		    if (c != ' ') { /* protocol error */ c = EOF; break; }
+
+		    c = chomp(be->in,
+			      "ANNOTATION \"\" "
+			      "\"/vendor/cmu/cyrus-imapd/freespace\" "
+			      "(\"value.shared\" \"");
+		    if (c == EOF) {
+			/* we don't care about this response */
+			eatline(be->in, c);
+			continue;
+		    }
+
+		    /* read uidvalidity */
+		    while (isdigit(c = prot_getc(be->in))) {
+			avail *= 10;
+			avail += c - '0';
+		    }
+		    if (c != '\"') { c = EOF; break; }
+		    eatline(be->in, c); /* we don't care about the rest of the line */
+		}
+		if (c != EOF) {
+		    prot_ungetc(c, be->in);
+
+		    /* we should be looking at the tag now */
+		    eatline(be->in, c);
+		}
+		if (c == EOF) {
+		    /* uh oh, we're not happy */
+		    fatal("Lost connection to backend", EC_UNAVAILABLE);
+		}
+		if (avail > max_avail) {
+		    server = cur_server;
+		    max_avail = avail;
+		}
+	    }
+
+	    /* move to next server */
+	    cur_server = next_server;
+	}
+
+	if (server) server = xstrdup(server);
+
+	free(tmpbuf);
+    }
+
+    return server;
+}
