@@ -42,7 +42,7 @@
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * $Id: ipurge.c,v 1.32 2009/02/09 05:01:57 brong Exp $
+ * $Id: ipurge.c,v 1.33 2009/03/26 00:02:20 brong Exp $
  */
 
 #include <config.h>
@@ -268,7 +268,7 @@ int purge_me(char *name, int matchlen __attribute__((unused)),
   (void) mailbox_lock_index(&the_box);
   the_box.index_lock_count = 1;
 
-  mailbox_expunge(&the_box, purge_check, &stats, EXPUNGE_FORCE);
+  mailbox_expunge(&the_box, purge_check, &stats, 0);
 
   sync_log_mailbox(the_box.name);
   mailbox_close(&the_box);
