@@ -39,7 +39,7 @@
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * $Id: mboxlist.c,v 1.263 2009/02/09 05:04:38 brong Exp $
+ * $Id: mboxlist.c,v 1.270 2009/07/28 02:46:23 brong Exp $
  */
 
 #include <config.h>
@@ -514,15 +514,15 @@ mboxlist_mycreatemailboxcheck(char *name,
 	    defaultacl = identifier = 
 		xstrdup(config_getstring(IMAPOPT_DEFAULTACL));
 	    for (;;) {
-		while (*identifier && isspace((int) *identifier)) identifier++;
+		while (*identifier && Uisspace(*identifier)) identifier++;
 		rights = identifier;
-		while (*rights && !isspace((int) *rights)) rights++;
+		while (*rights && !Uisspace(*rights)) rights++;
 		if (!*rights) break;
 		*rights++ = '\0';
-		while (*rights && isspace((int) *rights)) rights++;
+		while (*rights && Uisspace(*rights)) rights++;
 		if (!*rights) break;
 		p = rights;
-		while (*p && !isspace((int) *p)) p++;
+		while (*p && !Uisspace(*p)) p++;
 		if (*p) *p++ = '\0';
 		cyrus_acl_set(&acl, identifier, ACL_MODE_SET, cyrus_acl_strtomask(rights),
 			(cyrus_acl_canonproc_t *)0, (void *)0);
@@ -532,13 +532,26 @@ mboxlist_mycreatemailboxcheck(char *name,
 	}
 
 	if (!partition) {  
-	    partition = (char *)config_defpartition;
-	    if (strlen(partition) > MAX_PARTITION_LEN) {
-		/* Configuration error */
-		fatal("name of default partition is too long", EC_CONFIG);
+	    if (config_mupdate_server &&
+		(config_mupdate_config == IMAP_ENUM_MUPDATE_CONFIG_STANDARD) &&
+		!config_getstring(IMAPOPT_PROXYSERVERS)) {
+		/* proxy-only server -- caller will find a server */
+		partition = NULL;
+	    }
+	    else {
+		/* use defaultpartition if specified */
+		partition = (char *)config_defpartition;
+
+		/* otherwise find partition with most available space */
+		if (!partition) partition = find_free_partition(NULL);
+
+		if (strlen(partition) > MAX_PARTITION_LEN) {
+		    /* Configuration error */
+		    fatal("name of default partition is too long", EC_CONFIG);
+		}
 	    }
 	}
-	partition = xstrdup(partition);
+	if (partition) partition = xstrdup(partition);
     }
 
     if (newpartition) *newpartition = partition;
@@ -962,7 +975,7 @@ mboxlist_delayed_deletemailbox(const char *name, int isadmin, char *userid,
     /* Get mboxlist_renamemailbox to do the hard work. No ACL checks needed */
     r = mboxlist_renamemailbox((char *)name, newname, partition,
                                1 /* isadmin */, userid,
-                               auth_state, force);
+                               auth_state, force, 1);
 
     /* don't forget to log the rename! */
     sync_log_mailbox_double((char *)name, newname);
@@ -1144,7 +1157,8 @@ int mboxlist_deletemailbox(const char *name, int isadmin, char *userid,
  */
 int mboxlist_renamemailbox(char *oldname, char *newname, char *partition, 
 			   int isadmin, char *userid, 
-			   struct auth_state *auth_state, int forceuser)
+			   struct auth_state *auth_state, int forceuser,
+                           int ignorequota)
 {
     int r;
     long access;
@@ -1350,7 +1364,7 @@ int mboxlist_renamemailbox(char *oldname, char *newname, char *partition,
 	/* Rename the actual mailbox */
 	r = mailbox_rename_copy(&oldmailbox, newname, newpartition,
 				NULL, NULL, &newmailbox,
-				isusermbox ? userid : NULL);
+				isusermbox ? userid : NULL, ignorequota);
 	if (r) {
 	    goto done;
 	} else {
@@ -1921,7 +1935,7 @@ static int find_p(void *rockp,
     long matchlen;
 
     /* don't list mailboxes outside of the default domain */
-    if (!rock->domainlen && !rock->isadmin && strchr(key, '!')) return 0; 
+    if (!rock->domainlen && !rock->isadmin && memchr(key, '!', keylen)) return 0; 
 
     minmatch = 0;
     if (rock->inboxoffset) {
