@@ -39,7 +39,7 @@
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * $Id: mupdate.c,v 1.107 2009/02/09 05:01:58 brong Exp $
+ * $Id: mupdate.c,v 1.111 2009/04/30 18:20:58 murch Exp $
  */
 
 #include <config.h>
@@ -135,6 +135,8 @@ struct conn {
 #else
     void *tlsconn;
 #endif
+    void *tls_comp;     /* TLS compression method, if any */
+    int compress_done;  /* have we done a successful compress? */
 
     int idle;
     
@@ -223,6 +225,7 @@ void cmd_list(struct conn *C, const char *tag, const char *host_prefix);
 void cmd_startupdate(struct conn *C, const char *tag,
 		     struct stringlist *partial);
 void cmd_starttls(struct conn *C, const char *tag);
+void cmd_compress(struct conn *C, const char *tag, const char *alg);
 void shut_down(int code);
 static int reset_saslconn(struct conn *c);
 void database_init();
@@ -755,11 +758,11 @@ mupdate_docmd_result_t docmd(struct conn *c)
 	goto nextcmd;
     }
     
-    if (islower((unsigned char) c->cmd.s[0])) {
+    if (Uislower(c->cmd.s[0])) {
 	c->cmd.s[0] = toupper((unsigned char) c->cmd.s[0]);
     }
     for (p = &(c->cmd.s[1]); *p; p++) {
-	if (isupper((unsigned char) *p)) *p = tolower((unsigned char) *p);
+	if (Uisupper(*p)) *p = tolower((unsigned char) *p);
     }
     
     switch (c->cmd.s[0]) {
@@ -803,7 +806,20 @@ mupdate_docmd_result_t docmd(struct conn *c)
 	}
 	else goto badcmd;
 	break;
-	
+
+#ifdef HAVE_ZLIB
+    case 'C':
+	if (!strcmp(c->cmd.s, "Compress")) {
+	    if (ch != ' ') goto missingargs;
+	    ch = getstring(c->pin, c->pout, &(c->arg1));
+	    CHECKNEWLINE(c, ch);
+
+	    cmd_compress(c, c->tag.s, c->arg1.s);
+	}	
+	else goto badcmd;
+	break;
+#endif
+
     case 'D':
 	if (!c->userid) goto nologin;
 	else if (!strcmp(c->cmd.s, "Deactivate")) {
@@ -924,6 +940,14 @@ mupdate_docmd_result_t docmd(struct conn *c)
 		goto nextcmd;
 	    }
 		
+	    /* if we've already done COMPRESS fail */
+	    if (c->compress_done) {
+		prot_printf(c->pout, 
+			    "%s BAD Can't Starttls after Compress\r\n",
+			    c->tag.s);
+		goto nextcmd;
+	    }
+		
 	    /* check if already did a successful tls */
 	    if (c->tlsconn) {
 		prot_printf(c->pout, 
@@ -1103,6 +1127,12 @@ static void dobanner(struct conn *c)
 	prot_printf(c->pout, "* STARTTLS\r\n");
     }
 
+#ifdef HAVE_ZLIB
+    if (!c->compress_done && !c->tls_comp) {
+	prot_printf(c->pout, "* COMPRESS \"DEFLATE\"\r\n");
+    }
+#endif
+
     prot_printf(c->pout, "* PARTIAL-UPDATE\r\n");
 
     prot_printf(c->pout,
@@ -1269,8 +1299,12 @@ static void *thread_main(void *rock __attribute__((unused)))
 	    /* Free all connections on idle_connlist.  Note that
 	     * any connection not currently on the idle_connlist will
 	     * instead be freed when they drop out of their docmd() below */
+	    struct conn *ni;
+
 	    pthread_mutex_lock(&idle_connlist_mutex); /* LOCK */
-	    for(C=idle_connlist; C; C=C->next_idle) {
+	    for(C=idle_connlist; C; C = ni) {
+		ni = C->next_idle;
+
 		prot_printf(C->pout,
 			    "* BYE \"no longer ready for connections\"\r\n");
 
@@ -1988,6 +2022,10 @@ void cmd_starttls(struct conn *C, const char *tag)
     prot_settls(C->pin, C->tlsconn);
     prot_settls(C->pout, C->tlsconn);
 
+#if (OPENSSL_VERSION_NUMBER >= 0x0090800fL)
+    C->tls_comp = (void *) SSL_get_current_compression(C->tlsconn);
+#endif
+
     /* Reissue capability banner */
     dobanner(C);
 }
@@ -1999,6 +2037,48 @@ void cmd_starttls(struct conn *C, const char *tag)
 }
 #endif /* HAVE_SSL */
 
+#ifdef HAVE_ZLIB
+void cmd_compress(struct conn *C, const char *tag, const char *alg)
+{
+    if (C->compress_done) {
+	prot_printf(C->pout,
+		    "%s BAD DEFLATE active via COMPRESS\r\n", tag);
+    }
+#if defined(HAVE_SSL) && (OPENSSL_VERSION_NUMBER >= 0x0090800fL)
+    else if (C->tls_comp) {
+	prot_printf(C->pout,
+		    "%s NO %s active via TLS\r\n",
+		    tag, SSL_COMP_get_name(C->tls_comp));
+    }
+#endif
+    else if (strcasecmp(alg, "DEFLATE")) {
+	prot_printf(C->pout,
+		    "%s NO Unknown COMPRESS algorithm: %s\r\n", tag, alg);
+    }
+    else if (ZLIB_VERSION[0] != zlibVersion()[0]) {
+	prot_printf(C->pout,
+		    "%s NO Error initializing %s (incompatible zlib version)\r\n",
+		    tag, alg);
+    }
+    else {
+	prot_printf(C->pout,
+		    "%s OK %s active\r\n", tag, alg);
+
+	/* enable (de)compression for the prot layer */
+	prot_setcompress(C->pin);
+	prot_setcompress(C->pout);
+
+	C->compress_done = 1;
+    }
+}
+#else
+void cmd_compress(struct conn *C, const char *tag, const char *alg)
+{
+    fatal("cmd_compress() executed, but COMPRESS isn't implemented!",
+	  EC_SOFTWARE);
+}
+#endif /* HAVE_ZLIB */
+
 void shut_down(int code) __attribute__((noreturn));
 void shut_down(int code)
 {
@@ -2243,54 +2323,64 @@ static int sync_findall_cb(char *name,
     return 0;
 }
 
-int mupdate_synchronize(mupdate_handle *handle) 
+int mupdate_synchronize_remote(mupdate_handle *handle,
+			       struct mbent_queue *remote_boxes,
+			       struct mpool *pool)
+{
+    struct sync_rock rock;
+  
+    if(!handle || !handle->saslcompleted) return 1;
+
+    rock.pool = pool;
+  
+    /* ask mupdate master for updates and set nonblocking */
+    prot_printf(handle->conn->out, "U01 UPDATE\r\n");
+  
+    syslog(LOG_NOTICE,
+	   "scarfing mailbox list from master mupdate server");
+
+    remote_boxes->head = NULL;
+    remote_boxes->tail = &(remote_boxes->head);
+  
+    rock.boxes = remote_boxes;
+  
+    /* If there is a fatal error, return, other errors ignore */
+    if (mupdate_scarf(handle, cmd_resync, &rock, 1, NULL) != 0) {
+	struct mbent *p=remote_boxes->head, *p_next=NULL;
+	while(p) {
+	    p_next = p->next;
+	    p = p_next;
+	}
+	return 1;
+    }
+
+    /* Make socket nonblocking now */
+    prot_NONBLOCK(handle->conn->in);
+
+    return 0;
+}
+
+int mupdate_synchronize(struct mbent_queue *remote_boxes, struct mpool *pool)
 {
     struct mbent_queue local_boxes;
-    struct mbent_queue remote_boxes;
     struct mbent *l,*r;
-    struct mpool *pool;
     struct sync_rock rock;
     char pattern[] = { '*', '\0' };
     struct txn *tid = NULL;
     int ret = 0;    
     int err = 0;
 
-    if(!handle || !handle->saslcompleted) return 1;
-
-    pool = new_mpool(131072); /* Arbitrary, but large (128k) */
     rock.pool = pool;
     
-    /* ask for updates and set nonblocking */
-    prot_printf(handle->conn->out, "U01 UPDATE\r\n");
-
     /* Note that this prevents other people from running an UPDATE against
      * us for the duration.  this is a GOOD THING */
     pthread_mutex_lock(&mailboxes_mutex); /* LOCK */
     
-    syslog(LOG_NOTICE, 
+    syslog(LOG_NOTICE,
 	   "synchronizing mailbox list with master mupdate server");
 
     local_boxes.head = NULL;
     local_boxes.tail = &(local_boxes.head);
-    remote_boxes.head = NULL;
-    remote_boxes.tail = &(remote_boxes.head);
-
-    rock.boxes = &remote_boxes;
-
-    /* If there is a fatal error, die, other errors ignore */
-    if (mupdate_scarf(handle, cmd_resync, &rock, 1, NULL) != 0) {
-	struct mbent *p=remote_boxes.head, *p_next=NULL;
-	while(p) {
-	    p_next = p->next;
-	    p = p_next;
-	}
-	
-	ret = 1;
-	goto done;	
-    }
-
-    /* Make socket nonblocking now */
-    prot_NONBLOCK(handle->conn->in);
 
     rock.boxes = &local_boxes;
 
@@ -2302,8 +2392,8 @@ int mupdate_synchronize(mupdate_handle *handle)
        move on, if not, fix them */
     /* If the local is before the next remote, delete it */
     /* If the next remote is before theis local, insert it and try again */
-    for(l = local_boxes.head, r = remote_boxes.head; l && r;
-	l = local_boxes.head, r = remote_boxes.head) 
+    for(l = local_boxes.head, r = remote_boxes->head; l && r;
+	l = local_boxes.head, r = remote_boxes->head) 
     {
 	int ret = strcmp(l->mailbox, r->mailbox);
 	if(!ret) {
@@ -2330,7 +2420,7 @@ int mupdate_synchronize(mupdate_handle *handle)
 	    }
 	    /* Okay, dump these two */
 	    local_boxes.head = l->next;
-	    remote_boxes.head = r->next;
+	    remote_boxes->head = r->next;
 	} else if (ret < 0) {
 	    /* Local without corresponding remote, delete it */
 		/*
@@ -2360,7 +2450,7 @@ int mupdate_synchronize(mupdate_handle *handle)
 				  (r->t == SET_RESERVE ?
 				   MBTYPE_RESERVE : 0),
 				  r->server, r->acl, &tid);
-	    remote_boxes.head = r->next;
+	    remote_boxes->head = r->next;
 	}
     }
 
@@ -2385,8 +2475,8 @@ int mupdate_synchronize(mupdate_handle *handle)
 				  (r->t == SET_RESERVE ?
 				   MBTYPE_RESERVE : 0),
 				  r->server, r->acl, &tid);
-	    remote_boxes.head = r->next;
-	    r = remote_boxes.head;
+	    remote_boxes->head = r->next;
+	    r = remote_boxes->head;
 	}
     }
 
@@ -2400,9 +2490,7 @@ int mupdate_synchronize(mupdate_handle *handle)
 	syslog(LOG_NOTICE, "mailbox list synchronization complete");
     }
 
- done:
     pthread_mutex_unlock(&mailboxes_mutex); /* UNLOCK */
-    free_mpool(pool);
     return ret;
 }
 
