@@ -41,7 +41,7 @@
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * $Id: imtest.c,v 1.124 2009/01/14 15:50:47 murch Exp $
+ * $Id: imtest.c,v 1.126 2009/04/23 17:10:07 murch Exp $
  */
 
 #include "config.h"
@@ -83,6 +83,7 @@
 #include "hash.h"
 #include "imparse.h"
 #include "iptostring.h"
+#include "util.h"
 #include "xmalloc.h"
 #include "xstrlcat.h"
 #include "xstrlcpy.h"
@@ -185,6 +186,7 @@ struct capa_cmd_t {
     char *resp;		/* end of capability response */
     char *tls;		/* [OPTIONAL] TLS capability string */
     char *auth;		/* [OPTIONAL] AUTH capability string */
+    char *compress;	/* [OPTIONAL] COMPRESS capability string */
     char *(*parse_mechlist)(const char *str, struct protocol_t *prot);
 			/* [OPTIONAL] parse capability string,
 			   returns space-separated list of mechs */
@@ -213,6 +215,12 @@ struct sasl_cmd_t {
 			   after AUTH with SASL security layer */
 };
 
+struct compress_cmd_t {
+    char *cmd;		/* compress command string */
+    char *ok;		/* success response string */
+    char *fail;		/* failure response string */
+};
+
 struct logout_cmd_t {
     char *cmd;		/* logout command string */
     char *resp;		/* logout response */
@@ -226,6 +234,7 @@ struct protocol_t {
     struct capa_cmd_t capa_cmd;
     struct tls_cmd_t tls_cmd;
     struct sasl_cmd_t sasl_cmd;
+    struct compress_cmd_t compress_cmd;
     int (*do_auth)(struct sasl_cmd_t *sasl_cmd, void *rock,
 		   char *mech, char *mechlist);
 			/* [OPTIONAL] perform protocol-specific
@@ -1463,7 +1472,8 @@ enum {
 };
 
 static char *ask_capability(struct protocol_t *prot,
-			    int *supports_starttls, int automatic)
+			    int *supports_starttls, int *supports_compress,
+			    int automatic)
 {
     char str[1024] = "";
     char *ret = NULL, *tmp, *resp;
@@ -1495,6 +1505,12 @@ static char *ask_capability(struct protocol_t *prot,
 	    *supports_starttls = 1;
 	}
 	
+	/* check for compress */
+	if (prot->capa_cmd.compress &&
+	    strstr(str, prot->capa_cmd.compress) != NULL) {
+	    *supports_compress = 1;
+	}
+	
 	/* check for auth */
 	if (prot->capa_cmd.auth &&
 	    (tmp = strstr(str, prot->capa_cmd.auth)) != NULL) {
@@ -1716,12 +1732,12 @@ static int imap_pipe_oneline(char *buf, int len, void *rock) {
 	   buf[len-1] == '\n' && buf[len-1] == '\r' && buf[len-2] == '}') {
 	    /* possible literal, with \r */
 	    i = len-4;
-	    while(i > 0 && buf[i] != '{' && isdigit((int)buf[i])) i--;
+	    while(i > 0 && buf[i] != '{' && Uisdigit(buf[i])) i--;
 	    if(buf[i] == '{') text->inLiteral = atoi(buf + i + 1);
 	} else if(len > 3 && buf[len-1] == '\n' && buf[len-2] == '}') {
 	    /* possible literal, no \r -- hack for terminals*/
 	    i = len-3;
-	    while(i > 0 && buf[i] != '{' && isdigit((int)buf[i])) i--;
+	    while(i > 0 && buf[i] != '{' && Uisdigit(buf[i])) i--;
 	    if(buf[i] == '{') text->inLiteral = atoi(buf + i + 1);
 	}
 
@@ -2212,6 +2228,12 @@ void usage(char *prog, char *prot)
 	printf("  -t file  : Enable TLS. file has the TLS public and private keys\n"
 	       "             (specify \"\" to not use TLS for authentication)\n");
 #endif /* HAVE_SSL */
+#ifdef HAVE_ZLIB
+    if (!strcasecmp(prot, "imap") || !strcasecmp(prot, "mupdate")) {
+	printf("  -q       : Enable %s COMPRESSion"
+	       " (before last authentication attempt)\n", prot);
+    }
+#endif /* HAVE_ZLIB */
     printf("  -c       : enable challenge prompt callbacks\n"
 	   "             (enter one-time password instead of secret pass-phrase)\n");
     printf("  -n       : number of auth attempts (default=1)\n");
@@ -2226,68 +2248,78 @@ void usage(char *prog, char *prot)
 static struct protocol_t protocols[] = {
     { "imap", "imaps", "imap",
       { 1, NULL, NULL },
-      { "C01 CAPABILITY", "C01 ", " STARTTLS", " AUTH=", &imap_parse_mechlist },
+      { "C01 CAPABILITY", "C01 ", " STARTTLS", " AUTH=", " COMPRESS=DEFLATE",
+	&imap_parse_mechlist },
       { "S01 STARTTLS", "S01 OK", "S01 NO", 0 },
       { "A01 AUTHENTICATE", 0, 0, "A01 OK", "A01 NO", "+ ", "*", NULL, 0 },
+      { "Z01 COMPRESS DEFLATE", "Z01 OK", "Z01 NO" },
       &imap_do_auth, { "Q01 LOGOUT", "Q01 " },
       &imap_init_conn, &generic_pipe, &imap_reset
     },
     { "pop3", "pop3s", "pop",
       { 0, "+OK", &pop3_parse_banner },
-      { "CAPA", ".", "STLS", "SASL ", NULL },
+      { "CAPA", ".", "STLS", "SASL ", NULL, NULL },
       { "STLS", "+OK", "-ERR", 0 },
       { "AUTH", 255, 0, "+OK", "-ERR", "+ ", "*", NULL, 0 },
+      { NULL, NULL, NULL, },
       &pop3_do_auth, { "QUIT", "+OK" }, NULL, NULL, NULL
     },
     { "nntp", "nntps", "nntp",
       { 0, "20", NULL },
-      { "CAPABILITIES", ".", "STARTTLS", "SASL ", NULL },
+      { "CAPABILITIES", ".", "STARTTLS", "SASL ", NULL, NULL },
       { "STARTTLS", "382", "580", 0 },
       { "AUTHINFO SASL", 512, 0, "28", "48", "383 ", "*", &nntp_parse_success, 0 },
+      { NULL, NULL, NULL, },
       &nntp_do_auth, { "QUIT", "205" }, NULL, NULL, NULL
     },
     { "lmtp", NULL, "lmtp",
       { 0, "220 ", NULL },
-      { "LHLO lmtptest", "250 ", "STARTTLS", "AUTH ", NULL },
+      { "LHLO lmtptest", "250 ", "STARTTLS", "AUTH ", NULL, NULL },
       { "STARTTLS", "220", "454", 0 },
       { "AUTH", 512, 0, "235", "5", "334 ", "*", NULL, 0 },
+      { NULL, NULL, NULL, },
       &xmtp_do_auth, { "QUIT", "221" },
       &xmtp_init_conn, &generic_pipe, &xmtp_reset
     },
     { "smtp", "smtps", "smtp",
       { 0, "220 ", NULL },
-      { "EHLO smtptest", "250 ", "STARTTLS", "AUTH ", NULL },
+      { "EHLO smtptest", "250 ", "STARTTLS", "AUTH ", NULL, NULL },
       { "STARTTLS", "220", "454", 0 },
       { "AUTH", 512, 0, "235", "5", "334 ", "*", NULL, 0 },
+      { NULL, NULL, NULL, },
       &xmtp_do_auth, { "QUIT", "221" },
       &xmtp_init_conn, &generic_pipe, &xmtp_reset
     },
     { "mupdate", NULL, "mupdate",
       { 1, "* OK", NULL },
-      { NULL , "* OK", "* STARTTLS", "* AUTH ", NULL },
+      { NULL , "* OK", "* STARTTLS", "* AUTH ", "* COMPRESS \"DEFLATE\"", NULL },
       { "S01 STARTTLS", "S01 OK", "S01 NO", 1 },
       { "A01 AUTHENTICATE", INT_MAX, 1, "A01 OK", "A01 NO", "", "*", NULL, 0 },
+      { "Z01 COMPRESS \"DEFLATE\"", "Z01 OK", "Z01 NO" },
       NULL, { "Q01 LOGOUT", "Q01 " }, NULL, NULL, NULL
     },
     { "sieve", NULL, SIEVE_SERVICE_NAME,
       { 1, "OK", NULL },
-      { "CAPABILITY", "OK", "\"STARTTLS\"", "\"SASL\" ", NULL },
+      { "CAPABILITY", "OK", "\"STARTTLS\"", "\"SASL\" ", NULL, NULL },
       { "STARTTLS", "OK", "NO", 1 },
       { "AUTHENTICATE", INT_MAX, 1, "OK", "NO", NULL, "*", &sieve_parse_success, 1 },
+      { NULL, NULL, NULL, },
       NULL, { "LOGOUT", "OK" }, NULL, NULL, NULL
     },
     { "csync", NULL, "csync",
       { 1, "* OK", NULL },
-      { NULL , "* OK", "* STARTTLS", "* SASL ", NULL },
+      { NULL , "* OK", "* STARTTLS", "* SASL ", NULL, NULL },
       { "STARTTLS", "OK", "NO", 1 },
       { "AUTHENTICATE", INT_MAX, 0, "OK", "NO", "+ ", "*", NULL, 0 },
+      { NULL, NULL, NULL, },
       NULL, { "EXIT", "OK" }, NULL, NULL, NULL
     },
     { NULL, NULL, NULL,
       { 0, NULL, NULL },
-      { NULL, NULL, NULL, NULL, NULL },
+      { NULL, NULL, NULL, NULL, NULL, NULL },
       { NULL, NULL, NULL, 0 },
       { NULL, 0, 0, NULL, NULL, NULL, NULL, NULL, 0 },
+      { NULL, NULL, NULL, },
       NULL, { NULL, NULL }, NULL, NULL, NULL
     }
 };
@@ -2313,8 +2345,8 @@ int main(int argc, char **argv)
     char *tls_keyfile="";
     char *port = "", *prot = "";
     int run_stress_test=0;
-    int dotls=0, dossl=0;
-    int server_supports_tls;
+    int dotls=0, dossl=0, docompress=0;
+    int server_supports_tls, server_supports_compress;
     char str[1024];
     const char *pidfile = NULL;
     void *rock = NULL;
@@ -2336,11 +2368,18 @@ int main(int argc, char **argv)
     prog = strrchr(argv[0], '/') ? strrchr(argv[0], '/')+1 : argv[0];
 
     /* look at all the extra args */
-    while ((c = getopt(argc, argv, "P:scizvk:l:p:u:a:m:f:r:t:n:I:x:X:w:o:?h")) != EOF)
+    while ((c = getopt(argc, argv, "P:qscizvk:l:p:u:a:m:f:r:t:n:I:x:X:w:o:?h")) != EOF)
 	switch (c) {
 	case 'P':
 	    prot = optarg;
 	    break;
+	case 'q':
+#ifdef HAVE_ZLIB
+	    docompress=1;
+#else
+	    imtest_fatal("imtest was not compiled with zlib support\n");
+#endif
+	    break;
 	case 's':
 #ifdef HAVE_SSL
 	    dossl=1;
@@ -2559,7 +2598,8 @@ int main(int argc, char **argv)
 
 	if (protocol->banner.is_capa) {
 	    /* try to get the capabilities from the banner */
-	    mechlist = ask_capability(protocol, &server_supports_tls, AUTO_BANNER);
+	    mechlist = ask_capability(protocol, &server_supports_tls,
+				      &server_supports_compress, AUTO_BANNER);
 	    if (!mechlist && !server_supports_tls) {
 		/* found no capabilities in banner -> get them explicitly */
 		protocol->banner.is_capa = 0;
@@ -2579,7 +2619,8 @@ int main(int argc, char **argv)
 				 strlen(protocol->banner.resp)));
 	}	
 	if (!protocol->banner.is_capa) {
-	    mechlist = ask_capability(protocol, &server_supports_tls, AUTO_NO);
+	    mechlist = ask_capability(protocol, &server_supports_tls,
+				      &server_supports_compress, AUTO_NO);
 	}
 	
 #ifdef HAVE_SSL
@@ -2603,6 +2644,7 @@ int main(int argc, char **argv)
 			   "since they might have changed\n");
 		if (mechlist) free(mechlist);
 		mechlist = ask_capability(protocol, &server_supports_tls,
+					  &server_supports_compress,
 					  protocol->tls_cmd.auto_capa);
 	    }
 	    
@@ -2611,6 +2653,24 @@ int main(int argc, char **argv)
 	}
 #endif /* HAVE_SSL */
 
+#ifdef HAVE_ZLIB
+	if ((reauth == 1) && (docompress==1) && (server_supports_compress==1)) {
+	char *resp;
+
+	printf("C: %s\r\n", protocol->compress_cmd.cmd);
+	prot_printf(pout, "%s\r\n", protocol->compress_cmd.cmd);
+	prot_flush(pout);
+	    
+	resp = waitfor(protocol->compress_cmd.ok, protocol->compress_cmd.fail, 1);
+	    
+	if (!strncasecmp(resp, protocol->compress_cmd.ok,
+			 strlen(protocol->compress_cmd.ok))) {
+	    prot_setcompress(pin);
+	    prot_setcompress(pout);
+	}
+    }
+#endif /* HAVE_ZLIB */
+
 	if (noinitresp) {
 	    /* don't use an initial response, even if its supported */
 	    protocol->sasl_cmd.maxlen = 0;
@@ -2676,6 +2736,7 @@ int main(int argc, char **argv)
 		    prot_BLOCK(pin);
 		}
 		new_mechlist = ask_capability(protocol, &server_supports_tls,
+					      &server_supports_compress,
 					      protocol->sasl_cmd.auto_capa);
 		if (new_mechlist && strcmp(new_mechlist, mechlist)) {
 		    printf("WARNING: possible MITM attack: "
